# Non SND format audio test files

This folder contains files to test file formats
that cannot be stored with `audiofile.write()`
and can hence not been created on the fly.

The files stored here are downloaded from
https://docs.espressif.com/projects/esp-adf/en/latest/design-guide/audio-samples.html.
They are excerpts
from "Furious Freak"
and "Galway",
Kevin MacLeod (incompetech.com),
Licensed under Creative Commons:
[CC-BY-3.0](http://creativecommons.org/licenses/by/3.0/).
